diff --git a/.github/workflows/build.yml b/.github/workflows/build.yml
index 77691cc..e730e5c 100644
--- a/.github/workflows/build.yml
+++ b/.github/workflows/build.yml
@@ -88,25 +88,25 @@ jobs:
uses: actions/upload-artifact@v2
with:
name: HISP-Win64
- path: HorseIsleServer\HISPCli\bin\x64\Windows\net7.0\win-x64\publish\
+ path: HorseIsleServer\HISPd\bin\x64\Windows\net7.0\win-x64\publish\
- name: Upload win-x86
uses: actions/upload-artifact@v2
with:
name: HISP-Win32
- path: HorseIsleServer\HISPCli\bin\x86\Windows\net7.0\win-x86\publish\
+ path: HorseIsleServer\HISPd\bin\x86\Windows\net7.0\win-x86\publish\
- name: Upload win-arm
uses: actions/upload-artifact@v2
with:
name: HISP-WinARM
- path: HorseIsleServer\HISPCli\bin\arm\Windows\net7.0\windows-arm\publish\
+ path: HorseIsleServer\HISPd\bin\arm\Windows\net7.0\windows-arm\publish\
- name: Upload win-arm64
uses: actions/upload-artifact@v2
with:
name: HISP-WinARM64
- path: HorseIsleServer\HISPCli\bin\arm64\Windows\net7.0\windows-arm64\publish\
+ path: HorseIsleServer\HISPd\bin\arm64\Windows\net7.0\windows-arm64\publish\
- name: Upload win-x86-noobs
uses: actions/upload-artifact@v2
@@ -124,43 +124,43 @@ jobs:
uses: actions/upload-artifact@v2
with:
name: HISP-Linux64
- path: HorseIsleServer/HISPCli/bin/x64/Linux/net7.0/linux-x64/publish/
+ path: HorseIsleServer/HISPd/bin/x64/Linux/net7.0/linux-x64/publish/
- name: Upload linux-arm
uses: actions/upload-artifact@v2
with:
name: HISP-LinuxARM
- path: HorseIsleServer/HISPCli/bin/ARM/Linux/net7.0/linux-arm/publish/
+ path: HorseIsleServer/HISPd/bin/ARM/Linux/net7.0/linux-arm/publish/
- name: Upload linux-arm64
uses: actions/upload-artifact@v2
with:
name: HISP-LinuxARM64
- path: HorseIsleServer/HISPCli/bin/ARM64/Linux/net7.0/linux-arm64/publish/
+ path: HorseIsleServer/HISPd/bin/ARM64/Linux/net7.0/linux-arm64/publish/
- name: Upload mac-x64
uses: actions/upload-artifact@v2
with:
name: HISP-Mac64
- path: HorseIsleServer/HISPCli/bin/x64/MacOS/net7.0/osx-x64/publish/
+ path: HorseIsleServer/HISPd/bin/x64/MacOS/net7.0/osx-x64/publish/
- name: Upload mac-arm64
uses: actions/upload-artifact@v2
with:
name: HISP-MacARM64
- path: HorseIsleServer/HISPCli/bin/arm64/MacOS/net7.0/osx-arm64/publish/
+ path: HorseIsleServer/HISPd/bin/arm64/MacOS/net7.0/osx-arm64/publish/
- name: Upload android-arm
uses: actions/upload-artifact@v2
with:
name: HISP-AndroidARM
- path: HorseIsleServer/HISPCli/bin/arm/Android/net7.0/android-arm/publish/
+ path: HorseIsleServer/HISPd/bin/arm/Android/net7.0/android-arm/publish/
- name: Upload android-arm64
uses: actions/upload-artifact@v2
with:
name: HISP-AndroidARM64
- path: HorseIsleServer/HISPCli/bin/arm64/Android/net7.0/android-arm64/publish/
+ path: HorseIsleServer/HISPd/bin/arm64/Android/net7.0/android-arm64/publish/
- name: Upload Website (master)
diff --git a/.gitignore b/.gitignore
index cf7029a..8ba0395 100755
--- a/.gitignore
+++ b/.gitignore
@@ -9,8 +9,8 @@ HorseIsleServer/N00BS/obj/*
HorseIsleServer/N00BS/bin/*
HorseIsleServer/N00BS/flash.dll.idb
-HorseIsleServer/HISPCli/obj/*
-HorseIsleServer/HISPCli/bin/*
+HorseIsleServer/HISPd/obj/*
+HorseIsleServer/HISPd/bin/*
HorseIsleServer/Installer/Windows/*
diff --git a/HorseIsleServer/HISP.sln b/HorseIsleServer/HISP.sln
index 6b7a372..2796b1b 100644
--- a/HorseIsleServer/HISP.sln
+++ b/HorseIsleServer/HISP.sln
@@ -5,7 +5,7 @@ VisualStudioVersion = 17.2.32210.308
MinimumVisualStudioVersion = 10.0.40219.1
Project("{9A19103F-16F7-4668-BE54-9A1E7A4F7556}") = "LibHISP", "LibHISP\LibHISP.csproj", "{C48CBD82-AB30-494A-8FFA-4DE7069B5827}"
EndProject
-Project("{9A19103F-16F7-4668-BE54-9A1E7A4F7556}") = "HISPCli", "HISPCli\HISPCli.csproj", "{DEAD5CB0-C6B6-4B63-B1FB-A9F649CA1D27}"
+Project("{9A19103F-16F7-4668-BE54-9A1E7A4F7556}") = "HISPd", "HISPd\HISPd.csproj", "{DEAD5CB0-C6B6-4B63-B1FB-A9F649CA1D27}"
EndProject
Project("{9A19103F-16F7-4668-BE54-9A1E7A4F7556}") = "N00BS", "N00BS\N00BS.csproj", "{6B45A1E8-0F54-4BF7-AF48-41B9FE676570}"
EndProject
diff --git a/HorseIsleServer/HISPCli/HISPCli.csproj b/HorseIsleServer/HISPd/HISPd.csproj
similarity index 97%
rename from HorseIsleServer/HISPCli/HISPCli.csproj
rename to HorseIsleServer/HISPd/HISPd.csproj
index 2a28328..89f5d48 100644
--- a/HorseIsleServer/HISPCli/HISPCli.csproj
+++ b/HorseIsleServer/HISPd/HISPd.csproj
@@ -16,6 +16,12 @@
Resources.resx
+
+
+ PublicResXFileCodeGenerator
+ Resources.Designer.cs
+
+
false
false
diff --git a/HorseIsleServer/HISPCli/HISPCli.csproj.user b/HorseIsleServer/HISPd/HISPd.csproj.user
similarity index 100%
rename from HorseIsleServer/HISPCli/HISPCli.csproj.user
rename to HorseIsleServer/HISPd/HISPd.csproj.user
diff --git a/HorseIsleServer/HISPCli/Program.cs b/HorseIsleServer/HISPd/Program.cs
similarity index 100%
rename from HorseIsleServer/HISPCli/Program.cs
rename to HorseIsleServer/HISPd/Program.cs
diff --git a/HorseIsleServer/HISPCli/Properties/AssemblyInfo.cs b/HorseIsleServer/HISPd/Properties/AssemblyInfo.cs
similarity index 94%
rename from HorseIsleServer/HISPCli/Properties/AssemblyInfo.cs
rename to HorseIsleServer/HISPd/Properties/AssemblyInfo.cs
index e22bdd6..94a1006 100644
--- a/HorseIsleServer/HISPCli/Properties/AssemblyInfo.cs
+++ b/HorseIsleServer/HISPd/Properties/AssemblyInfo.cs
@@ -4,11 +4,11 @@ using System.Runtime.InteropServices;
// General Information about an assembly is controlled through the following
// set of attributes. Change these attribute values to modify the information
// associated with an assembly.
-[assembly: AssemblyTitle("HISP")]
+[assembly: AssemblyTitle("HISPd")]
[assembly: AssemblyDescription("Server Emulator for \"Horse Isle\"")]
[assembly: AssemblyConfiguration("")]
[assembly: AssemblyCompany("SilicaAndPina")]
-[assembly: AssemblyProduct("HISP")]
+[assembly: AssemblyProduct("HISPd")]
[assembly: AssemblyCopyright("Public Domain © 2022")]
[assembly: AssemblyTrademark("")]
[assembly: AssemblyCulture("")]
diff --git a/HorseIsleServer/HISPCli/Properties/Resources.resx b/HorseIsleServer/HISPd/Properties/Resources.resx
similarity index 100%
rename from HorseIsleServer/HISPCli/Properties/Resources.resx
rename to HorseIsleServer/HISPd/Properties/Resources.resx
diff --git a/HorseIsleServer/HISPCli/Properties/launchSettings.json b/HorseIsleServer/HISPd/Properties/launchSettings.json
similarity index 100%
rename from HorseIsleServer/HISPCli/Properties/launchSettings.json
rename to HorseIsleServer/HISPd/Properties/launchSettings.json
diff --git a/HorseIsleServer/HISPCli/Resources/HISP.service b/HorseIsleServer/HISPd/Resources/HISP.service
similarity index 88%
rename from HorseIsleServer/HISPCli/Resources/HISP.service
rename to HorseIsleServer/HISPd/Resources/HISP.service
index 20a12e6..f978da7 100644
--- a/HorseIsleServer/HISPCli/Resources/HISP.service
+++ b/HorseIsleServer/HISPd/Resources/HISP.service
@@ -27,7 +27,7 @@ User=horseisle
Group=horseisle
WorkingDirectory=/etc/hisp
-ExecStart=/usr/bin/HISPCli
+ExecStart=/usr/bin/HISPd
Environment=USER=horseisle HOME=/etc/hisp/home HISP_BASE_DIR=/etc/hisp HISP_CONF_FILE=/etc/hisp/server.properties
diff --git a/HorseIsleServer/HISPCli/icon.ico b/HorseIsleServer/HISPd/icon.ico
similarity index 100%
rename from HorseIsleServer/HISPCli/icon.ico
rename to HorseIsleServer/HISPd/icon.ico
diff --git a/HorseIsleServer/LibHISP/Properties/Resources.Designer.cs b/HorseIsleServer/LibHISP/Properties/Resources.Designer.cs
index 34853c1..e4e90e4 100644
--- a/HorseIsleServer/LibHISP/Properties/Resources.Designer.cs
+++ b/HorseIsleServer/LibHISP/Properties/Resources.Designer.cs
@@ -1,147 +1,145 @@
-//------------------------------------------------------------------------------
-//
-// This code was generated by a tool.
-// Runtime Version:4.0.30319.42000
-//
-// Changes to this file may cause incorrect behavior and will be lost if
-// the code is regenerated.
-//
-//------------------------------------------------------------------------------
-
-namespace HISP.Properties {
- using System;
-
-
- ///
- /// A strongly-typed resource public class, for looking up localized strings, etc.
- ///
- // This public class was auto-generated by the StronglyTypedResourceBuilder
- // public class via a tool like ResGen or Visual Studio.
- // To add or remove a member, edit your .ResX file then rerun ResGen
- // with the /str option, or rebuild your VS project.
- [global::System.CodeDom.Compiler.GeneratedCodeAttribute("System.Resources.Tools.StronglyTypedResourceBuilder", "16.0.0.0")]
- [global::System.Diagnostics.DebuggerNonUserCodeAttribute()]
- [global::System.Runtime.CompilerServices.CompilerGeneratedAttribute()]
- internal class Resources {
-
- private static global::System.Resources.ResourceManager resourceMan;
-
- private static global::System.Globalization.CultureInfo resourceCulture;
-
- [global::System.Diagnostics.CodeAnalysis.SuppressMessageAttribute("Microsoft.Performance", "CA1811:AvoidUncalledPrivateCode")]
- internal Resources() {
- }
-
- ///
- /// Returns the cached ResourceManager instance used by this public class.
- ///
- [global::System.ComponentModel.EditorBrowsableAttribute(global::System.ComponentModel.EditorBrowsableState.Advanced)]
- internal static global::System.Resources.ResourceManager ResourceManager {
- get {
- if (object.ReferenceEquals(resourceMan, null)) {
- global::System.Resources.ResourceManager temp = new global::System.Resources.ResourceManager("HISP.Properties.Resources", typeof(Resources).Assembly);
- resourceMan = temp;
- }
- return resourceMan;
- }
- }
-
- ///
- /// Overrides the current thread's CurrentUICulture property for all
- /// resource lookups using this strongly typed resource public class.
- ///
- [global::System.ComponentModel.EditorBrowsableAttribute(global::System.ComponentModel.EditorBrowsableState.Advanced)]
- internal static global::System.Globalization.CultureInfo Culture {
- get {
- return resourceCulture;
- }
- set {
- resourceCulture = value;
- }
- }
-
- ///
+//------------------------------------------------------------------------------
+//
+// This code was generated by a tool.
+// Runtime Version:4.0.30319.42000
+//
+// Changes to this file may cause incorrect behavior and will be lost if
+// the code is regenerated.
+//
+//------------------------------------------------------------------------------
+
+namespace HISP.Properties {
+ using System;
+
+
+ ///
+ /// A strongly-typed resource class, for looking up localized strings, etc.
+ ///
+ // This class was auto-generated by the StronglyTypedResourceBuilder
+ // class via a tool like ResGen or Visual Studio.
+ // To add or remove a member, edit your .ResX file then rerun ResGen
+ // with the /str option, or rebuild your VS project.
+ [global::System.CodeDom.Compiler.GeneratedCodeAttribute("System.Resources.Tools.StronglyTypedResourceBuilder", "17.0.0.0")]
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute()]
+ [global::System.Runtime.CompilerServices.CompilerGeneratedAttribute()]
+ public class Resources {
+
+ private static global::System.Resources.ResourceManager resourceMan;
+
+ private static global::System.Globalization.CultureInfo resourceCulture;
+
+ [global::System.Diagnostics.CodeAnalysis.SuppressMessageAttribute("Microsoft.Performance", "CA1811:AvoidUncalledPrivateCode")]
+ internal Resources() {
+ }
+
+ ///
+ /// Returns the cached ResourceManager instance used by this class.
+ ///
+ [global::System.ComponentModel.EditorBrowsableAttribute(global::System.ComponentModel.EditorBrowsableState.Advanced)]
+ public static global::System.Resources.ResourceManager ResourceManager {
+ get {
+ if (object.ReferenceEquals(resourceMan, null)) {
+ global::System.Resources.ResourceManager temp = new global::System.Resources.ResourceManager("HISP.Properties.Resources", typeof(Resources).Assembly);
+ resourceMan = temp;
+ }
+ return resourceMan;
+ }
+ }
+
+ ///
+ /// Overrides the current thread's CurrentUICulture property for all
+ /// resource lookups using this strongly typed resource class.
+ ///
+ [global::System.ComponentModel.EditorBrowsableAttribute(global::System.ComponentModel.EditorBrowsableState.Advanced)]
+ public static global::System.Globalization.CultureInfo Culture {
+ get {
+ return resourceCulture;
+ }
+ set {
+ resourceCulture = value;
+ }
+ }
+
+ ///
+ /// Looks up a localized string similar to Fri 15/04/2022
+ ///.
+ ///
+ public static string BuildDate {
+ get {
+ return ResourceManager.GetString("BuildDate", resourceCulture);
+ }
+ }
+
+ ///
+ /// Looks up a localized string similar to 12:19 am
+ ///.
+ ///
+ public static string BuildTime {
+ get {
+ return ResourceManager.GetString("BuildTime", resourceCulture);
+ }
+ }
+
+ ///
/// Looks up a localized string similar to <cross-domain-policy>
/// <allow-access-from domain="*" to-ports="12321" secure="false"/>
- ///</cross-domain-policy>.
- ///
- internal static string DefaultCrossDomain {
- get {
- return ResourceManager.GetString("DefaultCrossDomain", resourceCulture);
- }
- }
-
- ///
- /// Looks up a localized string similar to # HorseIsleServer Default Configuration File
- ///
+ ///</cross-domain-policy>.
+ ///
+ public static string DefaultCrossDomain {
+ get {
+ return ResourceManager.GetString("DefaultCrossDomain", resourceCulture);
+ }
+ }
+
+ ///
+ /// Looks up a localized string similar to # =======================
+ ///# Horse Isle Server Configuration
+ ///# =======================
+ ///#
+ ///# Configuration Version 1.3.1
+ ///# HISP was Created and Developed by SilicaAndPina
+ ///# However it is NOT COPYRIGHTED! This software is in the Public Domain!
+ ///#
///# Ip address the server will bind to (default: 0.0.0.0 ALL INTERFACES)
///ip=0.0.0.0
- ///# Port the server will bind to (default: 12321)
- ///port=12321
///
- ///# MariaDB Database
- ///db_ip=127.0.0.1
- ///db_name=beta
- ///db_username=root
- ///db_password=test123
- ///db_port=3306
- ///
- ///# Map Data
- ///map=HI1.MAP
- ///
- ///# JSON Format Data
- ///
- ///gamedata=gamedata.json
- ///
- ///# Cross-Domain Policy File
- ///crossdomain=CrossDomainPolicy.xml
- ///
- ///# Red Text Stating "Todays Note:"
- ///motd=April 11, 2020. New breed, C [rest of string was truncated]";.
- ///
- internal static string DefaultServerProperties {
- get {
- return ResourceManager.GetString("DefaultServerProperties", resourceCulture);
- }
- }
-
- ///
- /// UNKNOWN COMMIT HASH
- ///
- internal static string GitCommit {
- get {
- return ResourceManager.GetString("GitCommit", resourceCulture);
- }
- }
-
- internal static string GitTag
- {
- get
- {
- return ResourceManager.GetString("GitTag", resourceCulture);
- }
- }
- internal static string GitBranch
- {
- get
- {
- return ResourceManager.GetString("GitBranch", resourceCulture);
- }
- }
- internal static string BuildDate
- {
- get
- {
- return ResourceManager.GetString("BuildDate", resourceCulture);
- }
- }
- internal static string BuildTime
- {
- get
- {
- return ResourceManager.GetString("BuildTime", resourceCulture);
- }
- }
-
- }
-}
+ ///# Port the server will bind to defaults: (on beta.horseisle.com: 12321, on pinto.horseisle.com: 443)
+ ///# Though, 443 is likely to interfere with TLS, if you happen to have a web server [rest of string was truncated]";.
+ ///
+ public static string DefaultServerProperties {
+ get {
+ return ResourceManager.GetString("DefaultServerProperties", resourceCulture);
+ }
+ }
+
+ ///
+ /// Looks up a localized string similar to master
+ ///.
+ ///
+ public static string GitBranch {
+ get {
+ return ResourceManager.GetString("GitBranch", resourceCulture);
+ }
+ }
+
+ ///
+ /// Looks up a localized string similar to 03b55d148a1a109b501162095b1d04101c103cc3
+ ///.
+ ///
+ public static string GitCommit {
+ get {
+ return ResourceManager.GetString("GitCommit", resourceCulture);
+ }
+ }
+
+ ///
+ /// Looks up a localized string similar to v1.3
+ ///.
+ ///
+ public static string GitTag {
+ get {
+ return ResourceManager.GetString("GitTag", resourceCulture);
+ }
+ }
+ }
+}
diff --git a/HorseIsleServer/LibHISP/Properties/Resources.resx b/HorseIsleServer/LibHISP/Properties/Resources.resx
index 16a3a68..341785f 100644
--- a/HorseIsleServer/LibHISP/Properties/Resources.resx
+++ b/HorseIsleServer/LibHISP/Properties/Resources.resx
@@ -1,143 +1,142 @@
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
- text/microsoft-resx
-
-
- 2.0
-
-
- System.Resources.ResXResourceReader, System.Windows.Forms, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089
-
-
- System.Resources.ResXResourceWriter, System.Windows.Forms, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089
-
-
-
- ..\Resources\default_cross_domain.xml;System.String, mscorlib, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089;Windows-1252
-
-
- ..\Resources\server.properties;System.String, mscorlib, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089;Windows-1252
-
-
- ..\Resources\Versioning\GitCommit;System.String, mscorlib, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089;Windows-1252
-
-
- ..\Resources\Versioning\GitTag;System.String, mscorlib, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089;Windows-1252
-
-
- ..\Resources\Versioning\GitBranch;System.String, mscorlib, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089;Windows-1252
-
-
- ..\Resources\Versioning\BuildDate;System.String, mscorlib, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089;Windows-1252
-
-
- ..\Resources\Versioning\BuildTime;System.String, mscorlib, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089;Windows-1252
-
-
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+ text/microsoft-resx
+
+
+ 2.0
+
+
+ System.Resources.ResXResourceReader, System.Windows.Forms, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089
+
+
+ System.Resources.ResXResourceWriter, System.Windows.Forms, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089
+
+
+
+ ..\Resources\default_cross_domain.xml;System.String, mscorlib, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089;utf-8
+
+
+ ..\Resources\server.properties;System.String, mscorlib, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089;utf-8
+
+
+ ..\Resources\Versioning\GitCommit;System.String, mscorlib, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089;utf-8
+
+
+ ..\Resources\Versioning\GitTag;System.String, mscorlib, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089;utf-8
+
+
+ ..\Resources\Versioning\GitBranch;System.String, mscorlib, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089;utf-8
+
+
+ ..\Resources\Versioning\BuildDate;System.String, mscorlib, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089;utf-8
+
+
+ ..\Resources\Versioning\BuildTime;System.String, mscorlib, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089;utf-8
+
\ No newline at end of file
diff --git a/HorseIsleServer/HISPCli/Properties/PublishProfiles/AndroidARM.pubxml b/HorseIsleServer/HISPd/Properties/PublishProfiles/AndroidARM.pubxml
similarity index 100%
rename from HorseIsleServer/HISPCli/Properties/PublishProfiles/AndroidARM.pubxml
rename to HorseIsleServer/HISPd/Properties/PublishProfiles/AndroidARM.pubxml
diff --git a/HorseIsleServer/HISPCli/Properties/PublishProfiles/AndroidARM64.pubxml b/HorseIsleServer/HISPd/Properties/PublishProfiles/AndroidARM64.pubxml
similarity index 100%
rename from HorseIsleServer/HISPCli/Properties/PublishProfiles/AndroidARM64.pubxml
rename to HorseIsleServer/HISPd/Properties/PublishProfiles/AndroidARM64.pubxml
diff --git a/HorseIsleServer/HISPCli/Properties/PublishProfiles/Linux64.pubxml b/HorseIsleServer/HISPd/Properties/PublishProfiles/Linux64.pubxml
similarity index 100%
rename from HorseIsleServer/HISPCli/Properties/PublishProfiles/Linux64.pubxml
rename to HorseIsleServer/HISPd/Properties/PublishProfiles/Linux64.pubxml
diff --git a/HorseIsleServer/HISPCli/Properties/PublishProfiles/LinuxARM.pubxml b/HorseIsleServer/HISPd/Properties/PublishProfiles/LinuxARM.pubxml
similarity index 100%
rename from HorseIsleServer/HISPCli/Properties/PublishProfiles/LinuxARM.pubxml
rename to HorseIsleServer/HISPd/Properties/PublishProfiles/LinuxARM.pubxml
diff --git a/HorseIsleServer/HISPCli/Properties/PublishProfiles/LinuxARM64.pubxml b/HorseIsleServer/HISPd/Properties/PublishProfiles/LinuxARM64.pubxml
similarity index 100%
rename from HorseIsleServer/HISPCli/Properties/PublishProfiles/LinuxARM64.pubxml
rename to HorseIsleServer/HISPd/Properties/PublishProfiles/LinuxARM64.pubxml
diff --git a/HorseIsleServer/HISPCli/Properties/PublishProfiles/Osx64.pubxml b/HorseIsleServer/HISPd/Properties/PublishProfiles/Osx64.pubxml
similarity index 100%
rename from HorseIsleServer/HISPCli/Properties/PublishProfiles/Osx64.pubxml
rename to HorseIsleServer/HISPd/Properties/PublishProfiles/Osx64.pubxml
diff --git a/HorseIsleServer/HISPCli/Properties/PublishProfiles/OsxARM64.pubxml b/HorseIsleServer/HISPd/Properties/PublishProfiles/OsxARM64.pubxml
similarity index 100%
rename from HorseIsleServer/HISPCli/Properties/PublishProfiles/OsxARM64.pubxml
rename to HorseIsleServer/HISPd/Properties/PublishProfiles/OsxARM64.pubxml
diff --git a/HorseIsleServer/HISPCli/Properties/PublishProfiles/Win32.pubxml b/HorseIsleServer/HISPd/Properties/PublishProfiles/Win32.pubxml
similarity index 100%
rename from HorseIsleServer/HISPCli/Properties/PublishProfiles/Win32.pubxml
rename to HorseIsleServer/HISPd/Properties/PublishProfiles/Win32.pubxml
diff --git a/HorseIsleServer/HISPCli/Properties/PublishProfiles/Win64.pubxml b/HorseIsleServer/HISPd/Properties/PublishProfiles/Win64.pubxml
similarity index 100%
rename from HorseIsleServer/HISPCli/Properties/PublishProfiles/Win64.pubxml
rename to HorseIsleServer/HISPd/Properties/PublishProfiles/Win64.pubxml
diff --git a/HorseIsleServer/HISPCli/Properties/PublishProfiles/WinARM.pubxml b/HorseIsleServer/HISPd/Properties/PublishProfiles/WinARM.pubxml
similarity index 100%
rename from HorseIsleServer/HISPCli/Properties/PublishProfiles/WinARM.pubxml
rename to HorseIsleServer/HISPd/Properties/PublishProfiles/WinARM.pubxml
diff --git a/HorseIsleServer/HISPCli/Properties/PublishProfiles/WinARM64.pubxml b/HorseIsleServer/HISPd/Properties/PublishProfiles/WinARM64.pubxml
similarity index 100%
rename from HorseIsleServer/HISPCli/Properties/PublishProfiles/WinARM64.pubxml
rename to HorseIsleServer/HISPd/Properties/PublishProfiles/WinARM64.pubxml
diff --git a/HorseIsleServer/HISPCli/Properties/Resources.Designer.cs b/HorseIsleServer/HISPd/Properties/Resources.Designer.cs
similarity index 72%
rename from HorseIsleServer/HISPCli/Properties/Resources.Designer.cs
rename to HorseIsleServer/HISPd/Properties/Resources.Designer.cs
index 0ac88a9..4d75485 100644
--- a/HorseIsleServer/HISPCli/Properties/Resources.Designer.cs
+++ b/HorseIsleServer/HISPd/Properties/Resources.Designer.cs
@@ -1,70 +1,73 @@
-//------------------------------------------------------------------------------
-//
-// This code was generated by a tool.
-// Runtime Version:4.0.30319.42000
-//
-// Changes to this file may cause incorrect behavior and will be lost if
-// the code is regenerated.
-//
-//------------------------------------------------------------------------------
-
-namespace HISP.Cli.Properties {
- using System;
-
-
- ///
- /// A strongly-typed resource public class, for looking up localized strings, etc.
- ///
- // This public class was auto-generated by the StronglyTypedResourceBuilder
- // public class via a tool like ResGen or Visual Studio.
- // To add or remove a member, edit your .ResX file then rerun ResGen
- // with the /str option, or rebuild your VS project.
- [global::System.CodeDom.Compiler.GeneratedCodeAttribute("System.Resources.Tools.StronglyTypedResourceBuilder", "16.0.0.0")]
- [global::System.Diagnostics.DebuggerNonUserCodeAttribute()]
- [global::System.Runtime.CompilerServices.CompilerGeneratedAttribute()]
- internal class Resources {
-
- private static global::System.Resources.ResourceManager resourceMan;
-
- private static global::System.Globalization.CultureInfo resourceCulture;
-
- [global::System.Diagnostics.CodeAnalysis.SuppressMessageAttribute("Microsoft.Performance", "CA1811:AvoidUncalledPrivateCode")]
- internal Resources() {
- }
-
- ///
- /// Returns the cached ResourceManager instance used by this public class.
- ///
- [global::System.ComponentModel.EditorBrowsableAttribute(global::System.ComponentModel.EditorBrowsableState.Advanced)]
- internal static global::System.Resources.ResourceManager ResourceManager {
- get {
- if (object.ReferenceEquals(resourceMan, null)) {
- global::System.Resources.ResourceManager temp = new global::System.Resources.ResourceManager("HISP.Properties.Resources", typeof(Resources).Assembly);
- resourceMan = temp;
- }
- return resourceMan;
- }
- }
-
- ///
- /// Overrides the current thread's CurrentUICulture property for all
- /// resource lookups using this strongly typed resource public class.
- ///
- [global::System.ComponentModel.EditorBrowsableAttribute(global::System.ComponentModel.EditorBrowsableState.Advanced)]
- internal static global::System.Globalization.CultureInfo Culture {
- get {
- return resourceCulture;
- }
- set {
- resourceCulture = value;
- }
- }
-
- internal static string HISPService {
- get {
- return ResourceManager.GetString("HISPService", resourceCulture);
- }
- }
-
- }
-}
+//------------------------------------------------------------------------------
+//
+// This code was generated by a tool.
+// Runtime Version:4.0.30319.42000
+//
+// Changes to this file may cause incorrect behavior and will be lost if
+// the code is regenerated.
+//
+//------------------------------------------------------------------------------
+
+namespace HISP.Properties {
+ using System;
+
+
+ ///
+ /// A strongly-typed resource class, for looking up localized strings, etc.
+ ///
+ // This class was auto-generated by the StronglyTypedResourceBuilder
+ // class via a tool like ResGen or Visual Studio.
+ // To add or remove a member, edit your .ResX file then rerun ResGen
+ // with the /str option, or rebuild your VS project.
+ [global::System.CodeDom.Compiler.GeneratedCodeAttribute("System.Resources.Tools.StronglyTypedResourceBuilder", "17.0.0.0")]
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute()]
+ [global::System.Runtime.CompilerServices.CompilerGeneratedAttribute()]
+ public class Resources {
+
+ private static global::System.Resources.ResourceManager resourceMan;
+
+ private static global::System.Globalization.CultureInfo resourceCulture;
+
+ [global::System.Diagnostics.CodeAnalysis.SuppressMessageAttribute("Microsoft.Performance", "CA1811:AvoidUncalledPrivateCode")]
+ internal Resources() {
+ }
+
+ ///
+ /// Returns the cached ResourceManager instance used by this class.
+ ///
+ [global::System.ComponentModel.EditorBrowsableAttribute(global::System.ComponentModel.EditorBrowsableState.Advanced)]
+ public static global::System.Resources.ResourceManager ResourceManager {
+ get {
+ if (object.ReferenceEquals(resourceMan, null)) {
+ global::System.Resources.ResourceManager temp = new global::System.Resources.ResourceManager("HISP.Properties.Resources", typeof(Resources).Assembly);
+ resourceMan = temp;
+ }
+ return resourceMan;
+ }
+ }
+
+ ///
+ /// Overrides the current thread's CurrentUICulture property for all
+ /// resource lookups using this strongly typed resource class.
+ ///
+ [global::System.ComponentModel.EditorBrowsableAttribute(global::System.ComponentModel.EditorBrowsableState.Advanced)]
+ public static global::System.Globalization.CultureInfo Culture {
+ get {
+ return resourceCulture;
+ }
+ set {
+ resourceCulture = value;
+ }
+ }
+
+ ///
+ /// Looks up a localized resource of type System.Byte[].
+ ///
+ public static byte[] HISPService {
+ get {
+ object obj = ResourceManager.GetObject("HISPService", resourceCulture);
+ return ((byte[])(obj));
+ }
+ }
+ }
+}